<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Revised:	12/9/2010	ELL
// Added password feedback in message.
// Revised: 2/7/2012	ELL
// Added table prefix handling.
// Revised: 7/2/2012	ELL
// Adapted for website user page restrictions as well.
// Added insertion of salt into password before encrypting.
//
	include ("check_session.php");
	include ("encrypt_decrypt.php");

	$user_name = $_POST['user_name'];
	$password = $_POST['password'];
	$table = $_POST['table'];
	$no_prefix = $_REQUEST['no_prefix'];
	
	if (!isset($table) || ($table == "-not selected-") || ($table == ""))
	{
		echo MANAGE_USERS_NO_TABLE_TO_CHANGE_USER_PASSWORD_ERR . " " . CLICK_WORD . " <a href=\"manage_page_access.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " . MANAGE_USERS_NO_TABLE_TO_ADD_USER_TO_2_ERR;
		exit;
	}
	
	// Insert salt into password.
	$pos = rand(0, (strlen($password)-1) );
	$pass1 = substr($password, 0, $pos);
	$pass2 = substr($password, $pos);
	if ($_POST['website_user'] == 1)
		$salted_pass = $pass1 . BWB_PUB_SALT . $pass2;
	else
		$salted_pass = $pass1 . BWB_SALT . $pass2;
	//Encrypt password using user name as key.
	$encrypt_password = doEncrypt($salted_pass, $user_name);
	
	if (isset($no_prefix) && ($no_prefix == 1))
		$prefix = "";
	else
		$prefix = BWB_TABLE_PREFIX;

	// Change password.
	$query = "UPDATE `" . $prefix . $table . "` SET `password`='$encrypt_password' WHERE `UserID`='$user_name'";
		
	$cnt = $bwb_dbh->exec($query);
	
	$_SESSION['last_user'] = $user_name;
	
	echo "user_name=$user_name@@@@@password=$password";
?>
